'use strict';
import * as fs from 'node:fs';
import { SfCommand, Flags } from '@salesforce/sf-plugins-core';
import { Messages } from '@salesforce/core';
import { extractTestClasses } from '../../service/extractTestClasses.js';
Messages.importMessagesDirectoryFromMetaUrl(import.meta.url);
const messages = Messages.loadMessages('apex-tests-git-delta', 'delta');
export default class ApexTestDelta extends SfCommand {
    static summary = messages.getMessage('summary');
    static description = messages.getMessage('description');
    static examples = messages.getMessages('examples');
    static flags = {
        to: Flags.string({
            char: 't',
            summary: messages.getMessage('flags.to.summary'),
            required: true,
            default: 'HEAD',
        }),
        from: Flags.string({
            char: 'f',
            summary: messages.getMessage('flags.from.summary'),
            required: true,
        }),
        'regular-expression': Flags.string({
            char: 'e',
            summary: messages.getMessage('flags.regular-expression.summary'),
            required: true,
            default: '[Aa][Pp][Ee][Xx]::(.*?)::[Aa][Pp][Ee][Xx]',
        }),
        output: Flags.file({
            summary: messages.getMessage('flags.output.summary'),
            required: true,
            exists: false,
            default: 'runTests.txt',
        }),
        'sfdx-configuration': Flags.file({
            summary: messages.getMessage('flags.sfdx-configuration.summary'),
            char: 'c',
            required: true,
            exists: true,
            default: 'sfdx-project.json',
        }),
    };
    async run() {
        const { flags } = await this.parse(ApexTestDelta);
        const toGitRef = flags['to'];
        const fromGitRef = flags['from'];
        const regExFile = flags['regular-expression'];
        const output = flags['output'];
        const sfdxConfigFile = flags['sfdx-configuration'];
        const result = await extractTestClasses(fromGitRef, toGitRef, regExFile, sfdxConfigFile);
        const tests = result.validatedClasses;
        const warnings = result.warnings;
        fs.writeFileSync(output, tests);
        if (warnings.length > 0) {
            warnings.forEach((warning) => {
                this.warn(warning);
            });
        }
        this.log(tests);
        return { tests, warnings };
    }
}
//# sourceMappingURL=delta.js.map